{% extends 'spire/authentication/page/authentication_page.html' %}

{% load static %}

{% load crispy_forms_filters %}

{% block base_title %}Password Reset Form {% endblock %}

{% block authentication_page_content %}
    <h3>Password Reset</h3>
    <form method="post">
        {% csrf_token %}
        {{ form|crispy }}
        <button type="submit" class="w-100 btn btn-app-primary bg-app-primary mt-2">Submit</button>
    </form>
{% endblock %}