<div
    class="spinner-grow text-app-primary position-fixed top-50 start-50 translate-middle d-none"
    style="z-index: 1025"
    id="loading-icon"
    role="status"
>
    <span class="visually-hidden">
        Loading...
    </span>
</div>