{% extends 'spire/card/title_card.html' %}

{% block card_title %}
    Welcome Home
{% endblock %}

{% block card_button %}
    {% include 'spire/button/primary_button.html' with button_text='Add' button_icon='bi bi-plus' %}
{% endblock %}

{% block card_title_content %}
    <div class="row g-3">
        <div class="col-12">
            {% include 'spire/element/attribute_element.html' with attribute_title='Badges' %}
            {% include 'spire/badge/primary_badge.html' with badge_text='Primary' %}
            {% include 'spire/badge/accent_badge.html' with badge_text='Accent' %}
            {% include 'spire/badge/secondary_badge.html' with badge_text='Secondary' %}
            {% include 'spire/badge/danger_badge.html' with badge_text='Danger' %}
            {% include 'spire/badge/success_badge.html' with badge_text='Success' %}
            {% include 'spire/badge/warning_badge.html' with badge_text='Warning' %}
            {% include 'spire/badge/primary_outlined_badge.html' with badge_text='Primary Outlined' %}
            {% include 'spire/badge/secondary_outlined_badge.html' with badge_text='Secondary Outlined' %}
        </div>
        <div class="col-12">
            {% include 'spire/element/attribute_element.html' with attribute_title='Buttons' %}
            {% include 'spire/button/primary_button.html' with button_text='Primary' %}
            {% include 'spire/button/primary_dark_button.html' with button_text='Primary Dark' %}
            {% include 'spire/button/primary_outlined_button.html' with button_text='Primary Outlined' %}
            {% include 'spire/button/secondary_button.html' with button_text='Secondary' %}
            {% include 'spire/button/secondary_dark_button.html' with button_text='Secondary Dark' %}
            {% include 'spire/button/secondary_outlined_button.html' with button_text='Secondary Outlined' %}
            {% include 'spire/button/accent_button.html' with button_text='Accent' %}
            {% include 'spire/button/accent_dark_button.html' with button_text='Accent Dark' %}
            {% include 'spire/button/accent_outlined_button.html' with button_text='Accent Outlined' %}
            {% include 'spire/button/danger_button.html' with button_text='Danger' %}
            {% include 'spire/button/danger_dark_button.html' with button_text='Danger Dark' %}
            {% include 'spire/button/danger_outlined_button.html' with button_text='Danger Outlined' %}
            {% include 'spire/button/success_button.html' with button_text='Success' %}
            {% include 'spire/button/success_dark_button.html' with button_text='Success Dark' %}
            {% include 'spire/button/success_outlined_button.html' with button_text='Success Outlined' %}
            {% include 'spire/button/warning_button.html' with button_text='Warning' %}
            {% include 'spire/button/warning_dark_button.html' with button_text='Warning Dark' %}
            {% include 'spire/button/warning_outlined_button.html' with button_text='Warning Outlined' %}
        </div>

        <div class="col-12">
            {% include 'spire/accordion/accordion.html' %}
        </div>
{% endblock %}
