from django.apps import AppConfig


class NotificationAppConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'django_spire.notification.app'
    label = 'spire_notification_app'
