{% extends 'spire/item/item.html' %}

{% load humanize spire_core_tags %}

{% block item_content_gutter %}{% endblock %}
{% block item_padding %}pb-1 pt-1{% endblock %}
{% block item_title_col %} d-none {% endblock %}

{% block item_row_content %}
    <div class="col-12 pe-lg-0">
        <div class="row g-1 align-items-end">
            <div class="col text-secondary">
                <span class="fs--1">{{ comment.user.get_full_name|title }}</span>
                <span class="fs--2" data-bs-toggle="tooltip" data-bs-placement="top" title="{{ comment.created_datetime }}">
                     - {{ comment.created_datetime|naturaltime }} {% if comment.is_edited %}<span class="fst-italic">(edited)</span>{% endif %}
                </span>
            </div>
        </div>
    </div>

    <div class="col-12 pe-0 {% if not is_child %}mb-2{% endif %}">
        {{ comment.information | linebreaksbr }}
    </div>

{#    <div class="col-12 pe-0">#}
{#        {% if not is_child %}#}
{#            {% with comment.children.active.prefetch_user as children_list %}#}
{#                {% if children_list %}#}
{#                    <div class="bg-layer-two rounded border border-1 px-2 py-2 mb-2">#}
{#                        {% for comment in children_list %}#}
{#                            {% include 'spire/comment/item/comment_item.html' with is_child=True %}#}
{#                        {% endfor %}#}
{#                    </div>#}
{#                {% endif %}#}
{#            {% endwith %}#}
{#        {% endif %}#}
{#    </div>#}
{% endblock %}

{% block item_button %}
    {% include 'spire/comment/item/comment_item_ellipsis.html' %}
{% endblock %}
