{% extends 'spire/card/card.html' %}

{% load spire_core_tags %}

{% block card_padding_class %}p-0{% endblock %}

{% block card_content %}
    {% for user in user_list %}
        {% url 'user_account:form' pk=user.pk as edit_url %}
        
{#        {% if user.is_active %}#}
{#            {% url 'user_account:toggle_user_status' pk=user.pk as deactivate_url %}#}
{#        {% else %}#}
{#            {% url 'user_account:toggle_user_status' pk=user.pk as activate_url %}#}
{#        {% endif %} #}
{#        #}
{#        {% url 'user_account:toggle_user_status' pk=user.pk as delete_url %}#}
        {% include 'spire/user_account/item/user_profile_item.html' with custom_url_1=activate_url custom_name_1='Activate' edit_url=edit_url delete_url=deactivate_url delete_url_name='Deactivate' %}
    {% endfor %}
{% endblock %}
