<div class="mb-3">
    <div class="h5 text-app-primary mb-1 fw-bold">Maintenance Mode</div>
    The portal is currently in maintenance mode and will be back up shortly.
</div>
<div class="text-center">
    {% include 'spire/button/primary_dark_button.html' with button_text='Refresh Page' button_href=' ' %}
</div>
