{% extends 'spire/container/container.html' %}

{% load spire_core_tags %}

{% block container_title %}
    {{ user.username }}
{% endblock %}

{% block container_button %}
    {% url 'user_account:form' pk=project.pk as form_url %}
    {% include 'spire/button/base_button.html' with button_text='Edit' button_icon='bi bi-pencil-fill' href=form_url %}
{% endblock %}

{% block container_content %}
    {% include 'spire/user_account/card/user_detail_card.html' %}
{% endblock %}
