{% extends 'spire/base/base.html' %}

{% block base_body_content %}

    <div class="container-fluid ps-0">

        {% include 'spire/notification/notification.html' %}
        {% include 'spire/element/page_loading_element.html' %}

        {% block page_content %}
        {% endblock %}

        {% include 'spire/modal/dispatch_modal.html' %}

    </div>

{% endblock %}

