<div
    class="row g-2"
    x-data="{
            comment: new ModelObjectGlue('comment'),
            async init() {
                await this.comment.get()
            }
        }"
>
    <div class="col-12">
        {% include 'django_glue/form/field/text_field.html' with glue_model_field='comment.information' %}
    </div>
</div>