from django.apps import AppConfig


class HistoryActivityConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    label = 'spire_history_activity'
    name = 'django_spire.history.activity'
