{% extends 'spire/navigation/accordion/nav_accordion.html' %}

{% block nav_title %}
    Dashboards
{% endblock %}

{% block nav_icon %}bi bi-speedometer{% endblock %}

{% block accordion_content %}
    {% url 'home:home' as home_url %}
    {% include 'spire/navigation/elements/nav_link.html' with link_text='Home'  link_icon='bi bi-house' url=home_url %}
{% endblock %}
