{% extends 'spire/authentication/page/authentication_page.html' %}

{% load crispy_forms_filters %}

{% block base_title %}Password Reset{% endblock %}

{% block authentication_page_content %}
    <h3>Password Reset</h3>
    {% if token_fail %}
        <p>The password reset link was invalid, possibly because it has already been used. Please request a
            <a href="{% url 'user_account_reset_password' %}">new password reset</a>
        </p>
    {% else %}
        {% if form %}
            <form method="post">
                {% csrf_token %}
                {{ form|crispy }}
                <button type="submit" class="w-100 btn btn-app-primary bg-app-primary mt-2">Submit</button>
            </form>
        {% else %}
            <p>Your password is now changed</p>
        {% endif %}
    {% endif %}
{% endblock %}